"""
Small example script to demonstrate  the usage of session behind a proxy.
The proxy addresses should be stored in the environment variables HTTP_PROXY and HTTPS_PROXY
"""

import os

import requests

from requests_kerberos_proxy.adapters import HTTPAdapterWithProxyKerberosAuth

proxies = dict(
    http=os.environ.get("HTTP_PROXY"),
    https=os.environ.get("HTTPS_PROXY"),
)

session = requests.Session()
session.proxies = proxies

# kerberos authentication
http_adapter_with_proxy_kerberos_auth = HTTPAdapterWithProxyKerberosAuth()
session.mount("https://", http_adapter_with_proxy_kerberos_auth)

url = "https://example.com"
request = session.get(url)

print(request.status_code)



"""
Class that can be used to overload the HTTP adapter in order to include a proxy
"""

import requests
from urllib3.util import parse_url

import requests_kerberos as rk


class HTTPAdapterWithProxyKerberosAuth(requests.adapters.HTTPAdapter):
    @staticmethod
    def proxy_headers(proxy):
        headers = {}
        auth = rk.HTTPKerberosAuth()
        negotiate_details = auth.generate_request_header(
            None, parse_url(proxy).host, is_preemptive=True
        )
        headers["Proxy-Authorization"] = negotiate_details
        return headers



import os

import requests
from requests import Session

from .adapters import HTTPAdapterWithProxyKerberosAuth


def get_session(proxies=None) -> type(Session):
    session: Session = requests.Session()
    if proxies is None:
        # proxies not given via arguments. Try to get them via environment variables
        proxies = {}
        if http_proxy := os.environ.get("HTTP_PROXY"):
            proxies["http"] = http_proxy
        if https_proxy := os.environ.get("HTTPS_PROXY"):
            proxies["https"] = https_proxy

    if proxies:
        session.proxies = proxies
        # kerberos authentication
        http_adapter_with_proxy_kerberos_auth = HTTPAdapterWithProxyKerberosAuth()
        session.mount("https://", http_adapter_with_proxy_kerberos_auth)

    return session



"""
Small example script to demonstrate  the usage of session behind a proxy.
The proxy addresses should be stored in the environment variables HTTP_PROXY and HTTPS_PROXY
"""

import os
from requests_kerberos_proxy.util import get_session

proxies = dict(
    http=os.environ.get("HTTP_PROXY"),
    https=os.environ.get("HTTPS_PROXY"),
)

session = get_session(proxies=proxies)

url = "https://example.com"
request = session.get(url)

print(request.status_code)



"""
Small example script to demonstrate  the usage of session behind a proxy.
The proxy addresses should be stored in the environment variables HTTP_PROXY and HTTPS_PROXY
In this example we don't pass the proxies as an argument, but let is to the function to get them
"""
from requests_kerberos_proxy.util import get_session

session = get_session()

url = "https://example.com"
request = session.get(url)

print(request.status_code)



from requests import Session

from requests_kerberos_proxy.util import get_session

__author__ = "EVLT"
__copyright__ = "EVLT"
__license__ = "MIT"


def test_session():
    """Type Tests"""
    session = get_session()
    assert isinstance(session, Session)


